# Generated by Django 5.1.1 on 2024-09-29 14:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('dj_access_logger', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='accesslog',
            name='ipv4_address',
            field=models.GenericIPAddressField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='accesslog',
            name='ipv6_address',
            field=models.GenericIPAddressField(blank=True, null=True),
        ),
    ]
