# Generated by Django 5.1.1 on 2024-09-29 12:24

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='AccessLog',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('timestamp', models.DateTimeField(auto_now_add=True)),
                ('request_url', models.CharField(max_length=200)),
                ('request_headers', models.JSONField()),
                ('request_data', models.TextField()),
                ('request_method', models.CharField(max_length=10)),
                ('response_headers', models.JSONField()),
                ('response_data', models.TextField()),
                ('response_status_code', models.IntegerField()),
                ('ip_address', models.GenericIPAddressField(blank=True, null=True)),
                ('user_agent', models.CharField(blank=True, max_length=255, null=True)),
                ('referer', models.CharField(blank=True, max_length=255, null=True)),
                ('session_data', models.JSONField(blank=True, null=True)),
                ('cookies', models.JSONField(blank=True, null=True)),
                ('query_params', models.JSONField(blank=True, null=True)),
                ('request_path', models.CharField(blank=True, max_length=255, null=True)),
                ('request_protocol', models.CharField(blank=True, max_length=10, null=True)),
                ('request_encoding', models.CharField(blank=True, max_length=50, null=True)),
                ('response_time', models.FloatField(blank=True, null=True)),
                ('request_body_size', models.IntegerField(blank=True, null=True)),
                ('response_body_size', models.IntegerField(blank=True, null=True)),
                ('response_is_ok', models.BooleanField(default=False)),
            ],
        ),
    ]
